# Errors

::: bigfoot.BigfootError

::: bigfoot.UnmockedInteractionError

::: bigfoot.UnassertedInteractionsError

::: bigfoot.UnusedMocksError

::: bigfoot.VerificationError

::: bigfoot.InteractionMismatchError

::: bigfoot.MissingAssertionFieldsError

::: bigfoot.SandboxNotActiveError

::: bigfoot.ConflictError
